# Examples

- Example 1: [housing.py](housing.py)
- Example 2: [avocados.ipynb](avocados.ipynb)
- Example 3: [housing_different_levels.py](housing_different_levels.py)
- Example 4 (external repository): [housing_prices.ipynb](https://github.com/mikekeith52/housing_prices/blob/main/housing_prices.ipynb)

## See the blog posts:
1. [Part 1](https://towardsdatascience.com/introducing-scalecast-a-forecasting-library-pt-1-33b556d9b019)
2. [Part 2](https://towardsdatascience.com/may-the-forecasts-be-with-you-introducing-scalecast-pt-2-692f3f7f0be5)
3. [Part 3](https://towardsdatascience.com/forecast-on-3-levels-introducing-scalecast-pt-3-eb725e0be6c9)
4. [Bonus](https://medium.com/codex/forecasting-home-prices-in-your-zip-code-ab9be2c33d0e)